@@ -373,10 +373,12 @@ static void get_nss_certname(std::string& certname, Arc::Logger& logger) {
 static std::string signTypeToString(Arc::Signalgorithm alg) {
   switch(alg) {
     case Arc::SIGN_SHA1: return "sha1";
+#if (OPENSSL_VERSION_NUMBER >= 0x0090800fL)
     case Arc::SIGN_SHA224: return "sha224";
     case Arc::SIGN_SHA256: return "sha256";
     case Arc::SIGN_SHA384: return "sha384";
     case Arc::SIGN_SHA512: return "sha512";
+#endif
     default:
       break;
   }
@@ -424,20 +426,21 @@ int main(int argc, char *argv[]) {
                                     "  validityStart=time (e.g. 2008-05-29T10:20:30Z; if not specified, start from now)\n"
                                     "  validityEnd=time\n"
                                     "  validityPeriod=time (e.g. 43200 or 12h or 12H; if both validityPeriod and validityEnd\n"
-                                    "  not specified, the default is 12 hours for local proxy, and 168 hours for delegated\n"
-                                    "  proxy on myproxy server)\n"
+                                    "    not specified, the default is 12 hours for local proxy, and 168 hours for delegated\n"
+                                    "    proxy on myproxy server)\n"
                                     "  vomsACvalidityPeriod=time (e.g. 43200 or 12h or 12H; if not specified, the default\n"
-                                    "  is the minimum value of 12 hours and validityPeriod)\n"
+                                    "    is the minimum value of 12 hours and validityPeriod)\n"
                                     "  myproxyvalidityPeriod=time (lifetime of proxies delegated by myproxy server,\n"
-                                    "  e.g. 43200 or 12h or 12H; if not specified, the default is the minimum value of\n"
-                                    "  12 hours and validityPeriod (which is lifetime of the delegated proxy on myproxy server))\n"
+                                    "    e.g. 43200 or 12h or 12H; if not specified, the default is the minimum value of\n"
+                                    "    12 hours and validityPeriod (which is lifetime of the delegated proxy on myproxy server))\n"
                                     "  proxyPolicy=policy content\n"
                                     "  proxyPolicyFile=policy file\n"
                                     "  keybits=number - length of the key to generate. Default is 1024 bits.\n"
-                                    "  Special value 'inherit' is to use key length of signing certificate.\n"
+                                    "    Special value 'inherit' is to use key length of signing certificate.\n"
                                     "  signingAlgorithm=name - signing algorithm to use for signing public key of proxy.\n"
-                                    "  Possible values are sha1, sha2 (alias for sha256), sha224, sha256, sha384, sha512\n"
-                                    "  and inherit (use algorithm of signing certificate). Default is inherit.\n"
+                                    "    Possible values are sha1, sha2 (alias for sha256), sha224, sha256, sha384, sha512\n"
+                                    "    and inherit (use algorithm of signing certificate). Default is inherit.\n"
+                                    "    With old systems, only sha1 is acceptable.\n"
                                     "\n"
                                     "Supported information item names are:\n"
                                     "  subject - subject name of proxy certificate.\n"
@@ -607,7 +610,9 @@ int main(int argc, char *argv[]) {
 
   // If debug is specified as argument, it should be set before loading the configuration.
   if (!debug.empty())
-    Arc::Logger::getRootLogger().setThreshold(Arc::string_to_level(debug));
+    Arc::Logger::getRootLogger().setThreshold(Arc::istring_to_level(debug));
+
+  logger.msg(Arc::VERBOSE, "Running command: %s", options.GetCommandWithArguments());
 
   // This ensure command line args overwrite all other options
   if(!cert_path.empty())Arc::SetEnv("X509_USER_CERT", cert_path);
@@ -675,7 +680,7 @@ int main(int argc, char *argv[]) {
   if(voms_dir.empty()) voms_dir = Arc::GetEnv("X509_VOMS_DIR");
 
   if (debug.empty() && !usercfg.Verbosity().empty())
-    Arc::Logger::getRootLogger().setThreshold(Arc::string_to_level(usercfg.Verbosity()));
+    Arc::Logger::getRootLogger().setThreshold(Arc::istring_to_level(usercfg.Verbosity()));
 
   if (timeout > 0) usercfg.Timeout(timeout);
 
@@ -1405,6 +1410,7 @@ static void create_proxy(std::string& proxy_cert, Arc::Credential& signer,
   if(!signing_algorithm.empty() && signing_algorithm != "inherit") {
     if(signing_algorithm == "sha1") {
       cred_request.SetSigningAlgorithm(Arc::SIGN_SHA1);
+#if (OPENSSL_VERSION_NUMBER >= 0x0090800fL)
     } else if(signing_algorithm == "sha2") {
       cred_request.SetSigningAlgorithm(Arc::SIGN_SHA256);
     } else if(signing_algorithm == "sha224") {
@@ -1415,6 +1421,7 @@ static void create_proxy(std::string& proxy_cert, Arc::Credential& signer,
       cred_request.SetSigningAlgorithm(Arc::SIGN_SHA384);
     } else if(signing_algorithm == "sha512") {
       cred_request.SetSigningAlgorithm(Arc::SIGN_SHA512);
+#endif
     } else {
       throw std::runtime_error("Unknown signing algorithm specified: "+signing_algorithm);
     }
