@@ -90,9 +90,14 @@ namespace Arc {
     URL();
 
     /// Constructs a new URL from a string representation.
-    /* \param url      The string representation of URL
-       \param encoded  Set to true if URL is encoded according to RFC 3986 */
-    URL(const std::string& url, bool encoded = false);
+    /**
+     * \param url      The string representation of URL
+     * \param encoded  Set to true if URL is encoded according to RFC 3986
+     * \param defaultPort Port to use if 'url' doesn't specify port
+     * \param defaultPath Path to use if 'url' doesn't specify path
+     * \since Changed in 4.1.0. defaultPort and defaultPath arguments added.
+     **/
+    URL(const std::string& url, bool encoded = false, int defaultPort = -1, const std::string& defaultPath = "");
 
     /// Empty destructor.
     virtual ~URL();
