@@ -498,12 +498,16 @@ bool DTRGenerator::processReceivedDTR(DataStaging::DTR_ptr dtr) {
     lock.unlock();
     return true;
   }
-  lock.unlock();
 
-  // no DTRs left, clean up session dir if upload or failed download
-  lock.lock();
+  // No DTRs left, clean up session dir if upload or failed download
+  // But first add the DTR back to the active list to avoid race condition
+  // caused by calling hasJob() between removing from active and adding to
+  // finished, which results in job being submitted to DTR again
+  active_dtrs.insert(std::pair<std::string, std::string>(jobid, dtr->get_id()));
+
   bool finished_with_error = (finished_jobs.find(jobid) != finished_jobs.end() && !finished_jobs[jobid].empty());
   lock.unlock();
+
   if (dtr->get_source()->Local()) {
     // list of files to keep in session dir
     std::list<FileData> files;
@@ -545,8 +549,10 @@ bool DTRGenerator::processReceivedDTR(DataStaging::DTR_ptr dtr) {
     else if (delete_all_files(job.SessionDir(), files, false, job_uid, job_gid) == 2)
       logger.msg(Arc::WARNING, "%s: Failed to clean up session dir", jobid);
   }
-  // add to finished jobs (without overwriting existing error)
+  // add to finished jobs (without overwriting existing error) and finally
+  // remove from active
   lock.lock();
+  active_dtrs.erase(jobid);
   finished_jobs[jobid] += "";
 
   // log summary to DTR log and A-REX log
@@ -746,9 +752,26 @@ bool DTRGenerator::processReceivedJob(const GMJob& job) {
 
     staging = true;
     std::string source;
+    std::string original_source;
     std::string destination;
     if (job.get_state() == JOB_STATE_PREPARING) {
-      source = i->lfn;
+      // If ACIX should be used, use it as source and add original URL as
+      // location after DTR is created
+      if (!config.ACIXEndpoint().empty()) {
+        // Encode the original url so it is not parsed as part of the acix url
+        original_source = i->lfn;
+        Arc::URL acix_source(config.ACIXEndpoint() + "?url=" + Arc::uri_encode(original_source, false));
+        Arc::URL original_url(original_source);
+        // Add URL options to ACIX URL
+        for (std::map<std::string, std::string>::const_iterator opt = original_url.Options().begin();
+             opt != original_url.Options().end(); ++opt) {
+          acix_source.AddOption(opt->first, opt->second);
+        }
+        source = acix_source.fullstr();
+      }
+      else {
+        source = i->lfn;
+      }
       destination = "file:" + job.SessionDir() + i->pfn;
     }
     else {
@@ -799,6 +822,10 @@ bool DTRGenerator::processReceivedJob(const GMJob& job) {
       dtr->set_priority(job.get_local()->priority);
     // set whether to use A-REX host certificate for remote delivery services
     dtr->host_cert_for_remote_delivery(staging_conf.use_host_cert_for_remote_delivery);
+    // set real location if ACIX is used
+    if (!original_source.empty()) {
+      dtr->get_source()->AddLocation(Arc::URL(original_source), Arc::URL(original_source).ConnectionURL());
+    }
 
     DataStaging::DTRCacheParameters cache_parameters;
     CacheConfig cache_params(config.CacheParams());
@@ -858,6 +885,8 @@ int DTRGenerator::checkUploadedFiles(GMJob& job) {
   if (job.get_local() && !job.get_local()->sessiondir.empty()) session_dir = job.get_local()->sessiondir;
   else session_dir = config.SessionRoot(jobid) + '/' + jobid;
   // get input files list
+  std::list<std::string> uploaded_files;
+  std::list<std::string>* uploaded_files_ = NULL;
   std::list<FileData> input_files;
   std::list<FileData> input_files_ = input_files;
   if (!job_input_read_file(jobid, config, input_files)) {
@@ -865,6 +894,9 @@ int DTRGenerator::checkUploadedFiles(GMJob& job) {
     logger.msg(Arc::ERROR, "%s: Can't read list of input files", jobid);
     return 1;
   }
+  if (job_input_status_read_file(jobid, config, uploaded_files)) {
+    uploaded_files_ = &uploaded_files;
+  }
   int res = 0;
 
   // loop through each file and check
@@ -876,7 +908,7 @@ int DTRGenerator::checkUploadedFiles(GMJob& job) {
     }
     logger.msg(Arc::VERBOSE, "%s: Checking user uploadable file: %s", jobid, i->pfn);
     std::string error;
-    int err = user_file_exists(*i, session_dir, jobid, error, job_uid, job_gid);
+    int err = user_file_exists(*i, session_dir, jobid, error, job_uid, job_gid, uploaded_files_);
 
     if (err == 0) { // file is uploaded
       logger.msg(Arc::VERBOSE, "%s: User has uploaded file %s", jobid, i->pfn);
@@ -913,11 +945,22 @@ int DTRGenerator::checkUploadedFiles(GMJob& job) {
   return res;
 }
 
+bool match_list(const std::list<std::string>& slist, const std::string& str) {
+  for(std::list<std::string>::const_iterator s = slist.begin();
+               s != slist.end(); ++s) {
+    if(*s == str) return true;
+  }
+  return false;
+}
+
+
+
 int DTRGenerator::user_file_exists(FileData &dt,
                                    const std::string& session_dir,
                                    const std::string& jobid,
                                    std::string& error,
-                                   uid_t uid, gid_t gid) {
+                                   uid_t uid, gid_t gid,
+                                   const std::list<std::string>* uploaded_files) {
   struct stat st;
   std::string file_info(dt.lfn);
   if (file_info == "*.*") return 0; // do not wait for this file
@@ -927,7 +970,13 @@ int DTRGenerator::user_file_exists(FileData &dt,
   if (!Arc::FileStat(fname.c_str(), &st, uid, gid, false)) return 2;
 
   // if no size/checksum was supplied, return success
-  if (file_info.empty()) return 0;
+  if (file_info.empty()) {
+    // but check status first if avaialble
+    if (uploaded_files) {
+      if (!match_list(*uploaded_files, dt.pfn)) return 2;
+    }
+    return 0;
+  }
 
   if (S_ISDIR(st.st_mode)) {
     error = "Expected file. Directory found.";
@@ -990,7 +1039,9 @@ int DTRGenerator::user_file_exists(FileData &dt,
     }
   }
 
-  if (have_checksum) { // calculate checksum
+  if (uploaded_files) {
+    if (!match_list(*uploaded_files, dt.pfn)) return 2;
+  } else if (have_checksum) { // calculate checksum (if no better way)
     int h = -1;
     Arc::FileAccess* fa = NULL;
 
