@@ -1,6 +1,7 @@
 #ifndef APELDESTINATION_H
 #define APELDESTINATION_H
 
+#include "CARAggregation.h"
 #include "Destination.h"
 #include "JobLogFile.h"
 #include <stdexcept>
@@ -28,6 +29,8 @@ namespace Arc
     std::string output_dir;
     /** Max number of URs to put in a set before submitting it */
     int max_ur_set_size;
+    /** Require to set to ture this option by production message broker */
+    std::string use_ssl;
     /** Actual number of usage records in set */
     int urn;
     /** File name extension */
@@ -36,6 +39,8 @@ namespace Arc
     std::list<JobLogFile> joblogs;
     /** Usage Record set XML */
     Arc::XMLNode usagerecordset;
+    CARAggregation* aggregationManager;
+
     
     int submit_batch();
     Arc::MCC_Status send_request(const std::string &urset);
